"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateDeclarativeConfigFromSpec = void 0;
const common_1 = require("../common");
const services_1 = require("./services");
const upstreams_1 = require("./upstreams");
async function generateDeclarativeConfigFromSpec(api, tags) {
    try {
        const document = {
            _format_version: '1.1',
            services: await (0, services_1.generateServices)(api, tags),
        };
        if ((0, common_1.hasUpstreams)(api)) {
            document.upstreams = (0, upstreams_1.generateUpstreams)(api, tags);
        }
        const declarativeConfigResult = {
            type: 'kong-declarative-config',
            label: 'Kong Declarative Config',
            documents: [document],
            warnings: [],
        };
        /**
         * There was an [issue](https://github.com/Kong/studio/issues/93) that required us to stringify and parse the declarative config object containing circular dependencies.
         * However, that fix didn't seem to clear the issue of the circular dependencies completely.
         *
         * It is attempted to resolve the circular issue by bundling the openapi spec using SwaggerParser.bundle() method, which resolves all the schemas into $ref instead of dereferencing them.
         * Then, we would just dump the components part of it with $schema property, so any JSON parsing logic can refer to the components object.
         *
         * Therefore, JSON.parse(JSON.stringify(result)) doesn't seem to be needed any more.
         */
        return declarativeConfigResult;
    }
    catch (err) {
        throw new Error('Failed to generate spec: ' + err.message);
    }
}
exports.generateDeclarativeConfigFromSpec = generateDeclarativeConfigFromSpec;
//# sourceMappingURL=generate.js.map