"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.appendUpstreamToName = exports.generateUpstreams = void 0;
const common_1 = require("../common");
const kong_1 = require("../types/kong");
function generateUpstreams(api, tags) {
    const servers = api.servers || [];
    if (servers.length === 0) {
        return [];
    }
    // x-kong-upstream-defaults is free format so we do not want type checking.
    // If added, it would tightly couple these objects to Kong, and that would make future maintenance a lot harder.
    const upstreamDefaults = api[kong_1.xKongUpstreamDefaults] || {};
    if (typeof upstreamDefaults !== 'object') {
        throw new Error(`expected '${kong_1.xKongUpstreamDefaults}' to be an object`);
    }
    let name = (0, common_1.getName)(api);
    if ((0, common_1.hasUpstreams)(api)) {
        name = (0, exports.appendUpstreamToName)(name);
    }
    const upstream = {
        ...upstreamDefaults,
        name,
        targets: [],
        tags,
    };
    for (const server of servers) {
        const serverWithVars = (0, common_1.fillServerVariables)(server);
        const hostWithPort = (0, common_1.parseUrl)(serverWithVars).host;
        if (hostWithPort) {
            upstream.targets.push({
                target: hostWithPort,
                tags,
            });
        }
    }
    return [upstream];
}
exports.generateUpstreams = generateUpstreams;
const appendUpstreamToName = (name) => `${name}.upstream`;
exports.appendUpstreamToName = appendUpstreamToName;
//# sourceMappingURL=upstreams.js.map